@@ -1,10 +1,10 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apache.tcl,v 1.6 1999/02/03 21:05:01 jfontain Exp $}
+set rcsId {$Id: apache.tcl,v 1.8 1999/07/20 19:05:55 jfontain Exp $}
 
-package provide apache 1.1
-package require apacheutilities
+package provide apache 1.2
+package require apacheutilities 1.1
 
 
 namespace eval apache {
@@ -38,8 +38,10 @@ namespace eval apache {
     proc initialize {optionsName} {
         upvar $optionsName options
         variable url
+        variable data
 
-        set url [url options apache ?auto]
+        set url [url options host apache ?auto]
+        set data(identifier) apache($host)
     }
 
     proc update {} {
