@@ -1,9 +1,9 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apacheu.tcl,v 1.3 1999/02/03 21:05:25 jfontain Exp $}
+set rcsId {$Id: apacheu.tcl,v 1.5 1999/07/19 19:49:23 jfontain Exp $}
 
-package provide apacheutilities 1.0
+package provide apacheutilities 1.1
 package require http 2
 
 
@@ -25,8 +25,10 @@ proc ::http::Finish {token {errormsg ""}} {     ;# modified from http package so
 
 namespace eval apache {
 
-    proc url {optionsName moduleName {flag {}}} {     ;# works for both apache and apachex modules, flag can be ?auto, ?notable, ...
+    # works for both apache and apachex modules, flag can be ?auto, ?notable, ...
+    proc url {optionsName hostName moduleName {flag {}}} {
         upvar $optionsName options
+        upvar $hostName host
 
         if {![catch {set url $options(--remote)}]||![catch {set url $options(-r)}]} {
             if {[string first ? $url]>=0} {                                                         ;# we specify the flag ourselves
@@ -38,8 +40,11 @@ namespace eval apache {
                 append url /server-status                                                                             ;# use default
             }
             append url $flag
+            regsub {^http://} $url {} url                                               ;# eventually remove useless protocol header
+            scan $url {%[^/]} host
         } else {
             set url 127.0.0.1/server-status${flag}                                                ;# default for server on localhost
+            set host 127.0.0.1
         }
         return $url
     }
