@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: apachex.tcl,v 1.5 1999/07/20 19:05:55 jfontain Exp $}
+set rcsId {$Id: apachex.tcl,v 1.6 1999/08/27 20:01:01 jfontain Exp $}
 
 package provide apachex 1.2
 package require apacheutilities 1.1
@@ -95,8 +95,7 @@ namespace eval apachex {
                 set last($row,9) $data($row,9)                           ;# save megabytes for slot for dynamic traffic calculations
             }
         }
-        foreach name [array names data *,0] {                                                          ;# cleanup vanished rows data
-            set row $data($name)
+        foreach {name row} [array get data *,0] {                                                      ;# cleanup vanished rows data
             if {[info exists current($row)]} continue
             for {set column 0} {$column<=13} {incr column} {
                 unset data($row,$column)
