@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.20 1999/07/23 21:26:40 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.21 1999/08/27 20:20:35 jfontain Exp $}
 
 
 package provide arp 1.6
@@ -143,9 +143,8 @@ namespace eval arp {
             set data($row,5) $interface
             set current($address) {}
         }
-        foreach address [array names index] {                                                         ;# cleanup disappeared entries
+        foreach {address row} [array get index] {                                                     ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
-            set row $index($address)
             unset index($address) data($row,0) data($row,1) data($row,2) data($row,3)
         }
         incr data(updates)
