@@ -1,14 +1,14 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: canvhand.tcl,v 1.29 1999/07/17 19:46:46 jfontain Exp $}
+set rcsId {$Id: canvhand.tcl,v 2.2 1999/08/28 10:40:20 jfontain Exp $}
 
 class canvasWindowManager {
 
     class handles {       ;# embed widget in a frame with handles for resizing and moving inside a canvas acting as a window manager
 
         proc handles {this parentPath manager args} composite {[new frame $parentPath] $args} {
-            if {[string compare [winfo class $parentPath] Canvas]!=0} {
+            if {![string equal [winfo class $parentPath] Canvas]} {
                 error {parent must be the manager canvas}
             }
             set ($this,item) [$parentPath create window 0 0 -window $widget::($this,path) -anchor nw]
@@ -19,7 +19,7 @@ class canvasWindowManager {
         }
 
         proc ~handles {this} {
-            [set ($this,canvas)] delete [set ($this,item)] outline                       ;# delete canvas items (eventually outline)
+            $($this,canvas) delete $($this,item) outline                                 ;# delete canvas items (eventually outline)
         }
 
         proc options {this} {
@@ -46,7 +46,7 @@ class canvasWindowManager {
         }
 
         proc set-path {this value} {  ;### mandatory construction time option: eventually enforce or make a constructor argument ###
-            if {[set ($this,filled)]} {
+            if {$($this,filled)} {
                 error {cannot manage more than 1 widget}
             }
             if {![winfo exists $value]} {
@@ -63,19 +63,19 @@ class canvasWindowManager {
         }
 
         proc set-setheight {this value} {
-            [set ($this,canvas)] itemconfigure [set ($this,item)] -height $value
+            $($this,canvas) itemconfigure $($this,item) -height $value
         }
 
         proc set-setwidth {this value} {
-            [set ($this,canvas)] itemconfigure [set ($this,item)] -width $value
+            $($this,canvas) itemconfigure $($this,item) -width $value
         }
 
         proc set-setx {this value} {
-            [set ($this,canvas)] coords [set ($this,item)] $value [lindex [[set ($this,canvas)] coords [set ($this,item)]] end]
+            $($this,canvas) coords $($this,item) $value [lindex [$($this,canvas) coords $($this,item)] end]
         }
 
         proc set-sety {this value} {
-            [set ($this,canvas)] coords [set ($this,item)] [lindex [[set ($this,canvas)] coords [set ($this,item)]] 0] $value
+            $($this,canvas) coords $($this,item) [lindex [$($this,canvas) coords $($this,item)] 0] $value
         }
 
         proc set-static {this value} {
@@ -85,14 +85,14 @@ class canvasWindowManager {
         proc set-title {this value} {
             if {![info exists ($this,label)]} {
                 set ($this,label) [label $widget::($this,path).label -pady 0 -font $font::(smallNormal) -background gray -anchor w]
-                pack [set ($this,label)] -side top -fill x -before $composite::($this,-path)
+                pack $($this,label) -side top -fill x -before $composite::($this,-path)
                 if {[string length $composite::($this,-path)>0]} {
                     # always place before the displayed widget so that when the user shrinks the window too much,
                     # title area always remains visible
-                    pack [set ($this,label)] -before $composite::($this,-path)
+                    pack $($this,label) -before $composite::($this,-path)
                 }
             }
-            [set ($this,label)] configure -text $value
+            $($this,label) configure -text $value
             updateBindings $this $composite::($this,-static)
         }
 
@@ -116,7 +116,7 @@ class canvasWindowManager {
                 bind $path <ButtonRelease-1> "canvasWindowManager::handles::buttonRelease $this"
             }
             if {[info exists ($this,label)]} {                                                                         ;# title area
-                set path [set ($this,label)]
+                set path $($this,label)
                 if {$static} {
                     $path configure -cursor arrow
                     bind $path <Button1-Motion> {}
@@ -132,19 +132,19 @@ class canvasWindowManager {
         }
 
         proc buttonMotion {this x y} {
-            set (motion) {}
+            set ::canvasWindowManager::handles::(motion) {}
             updateOutline $this $x $y
         }
 
         proc buttonPress {this x y} {
-            set canvasWindowManager::handles::(xLast) $x                             ;### Tcl BUG: should be set ([xy]Last) $... ###
-            set canvasWindowManager::handles::(yLast) $y
+            set ::canvasWindowManager::handles::(xLast) $x
+            set ::canvasWindowManager::handles::(yLast) $y
             lifoLabel::push $global::messenger {}    ;# in case no other string is pushed before button release event pops messenger
             createOutline $this
         }
 
         proc toggleVisibility {this} {
-            if {[canvasWindowManager::raisedOnTop [set ($this,manager)] $composite::($this,-path)]} {
+            if {[canvasWindowManager::raisedOnTop $($this,manager) $composite::($this,-path)]} {
                 stack $this lower                               ;# else place below other windows so they get a chance to be visible
             } else {
                 stack $this raise                                              ;# place on top if partially hidden by another window
@@ -156,12 +156,13 @@ class canvasWindowManager {
             if {[info exists (motion)]} {                                                              ;# moving or resizing occured
                 updateGeometry $this
                 stack $this raise                                                   ;# always place widget on top after acting on it
-                unset (motion)
+                unset ::canvasWindowManager::handles::(motion)
             } else {                                                                                ;# no moving or resizing occured
                 toggleVisibility $this
             }
             destroyOutline $this
-            unset (xLast) (yLast) (hidden)
+            unset ::canvasWindowManager::handles::(xLast) ::canvasWindowManager::handles::(yLast)\
+                ::canvasWindowManager::handles::(hidden)
         }
 
         proc resize {this width height} {
@@ -172,20 +173,20 @@ class canvasWindowManager {
 
             set halfHeight [expr {($height/2)}]
             set ($this,topHandleBottom) [minimum $size $halfHeight]            ;# top corner handle bottom cannot exceed half height
-            set ($this,bottomHandleTop) [expr {$height-[set ($this,topHandleBottom)]}]
+            set ($this,bottomHandleTop) [expr {$height-$($this,topHandleBottom)}]
             # mid handle top cannot be to close to top corner handle bottom
-            set ($this,midHandleTop) [maximum [expr {$height/3}] [expr {[set ($this,topHandleBottom)]+$size}]]
+            set ($this,midHandleTop) [maximum [expr {$height/3}] [expr {$($this,topHandleBottom)+$size}]]
             # mid handle bottom limit cannot be greater than bottom corner handle top
-            set ($this,midHandleBottom) [minimum [expr {(2*$height)/3}] [expr {[set ($this,bottomHandleTop)]-$size}]]
+            set ($this,midHandleBottom) [minimum [expr {(2*$height)/3}] [expr {$($this,bottomHandleTop)-$size}]]
             # note: mid handle top can be greater than mid handle bottom when handle disappears
 
             set halfWidth [expr {($width/2)}]
             set ($this,leftHandleRight) [minimum $size $halfWidth]              ;# left corner handle right cannot exceed half width
-            set ($this,rightHandleLeft) [expr {$width-[set ($this,leftHandleRight)]}]
+            set ($this,rightHandleLeft) [expr {$width-$($this,leftHandleRight)}]
             # mid handle left cannot be less than left corner handle right
-            set ($this,midHandleLeft) [maximum [expr {$width/3}] [expr {[set ($this,leftHandleRight)]+$size}]]
+            set ($this,midHandleLeft) [maximum [expr {$width/3}] [expr {$($this,leftHandleRight)+$size}]]
             # mid handle right limit cannot be greater than right corner handle left
-            set ($this,midHandleRight) [minimum [expr {(2*$width)/3}] [expr {[set ($this,rightHandleLeft)]-$size}]]
+            set ($this,midHandleRight) [minimum [expr {(2*$width)/3}] [expr {$($this,rightHandleLeft)-$size}]]
             # note: mid handle left can be greater than mid handle right when handle disappears
         }
 
@@ -205,13 +206,13 @@ class canvasWindowManager {
                 set direction e
             }
             if {[info exists side]} {                                                                        ;# in a vertical border
-                if {$y<[set ($this,topHandleBottom)]} {
+                if {$y<$($this,topHandleBottom)} {
                     set cursor top_${side}_corner
                     append direction n
-                } elseif {$y>[set ($this,bottomHandleTop)]} {
+                } elseif {$y>$($this,bottomHandleTop)} {
                     set cursor bottom_${side}_corner
                     append direction s
-                } elseif {($y>[set ($this,midHandleTop)])&&($y<[set ($this,midHandleBottom)])} {
+                } elseif {($y>$($this,midHandleTop))&&($y<$($this,midHandleBottom))} {
                     set cursor ${side}_side
                 } else {
                     set cursor fleur
@@ -226,13 +227,13 @@ class canvasWindowManager {
                     set direction s
                 }
                 if {[info exists side]} {                                                                 ;# in an horizontal border
-                    if {$x<[set ($this,leftHandleRight)]} {
+                    if {$x<$($this,leftHandleRight)} {
                         set cursor ${side}_left_corner
                         append direction w
-                    } elseif {$x>[set ($this,rightHandleLeft)]} {
+                    } elseif {$x>$($this,rightHandleLeft)} {
                         set cursor ${side}_right_corner
                         append direction e
-                    } elseif {($x>[set ($this,midHandleLeft)])&&($x<[set ($this,midHandleRight)])} {
+                    } elseif {($x>$($this,midHandleLeft))&&($x<$($this,midHandleRight))} {
                         set cursor ${side}_side
                     } else {
                         set cursor fleur
@@ -240,7 +241,7 @@ class canvasWindowManager {
                     }
                 }
             }
-            if {[string compare $cursor [$widget::($this,path) cget -cursor]]!=0} {                ;# update cursor only when needed
+            if {![string equal $cursor [$widget::($this,path) cget -cursor]]} {                    ;# update cursor only when needed
                 $widget::($this,path) configure -cursor $cursor
                 update idletasks                                                ;# make cursor immediately visible for user feedback
             }
@@ -250,11 +251,11 @@ class canvasWindowManager {
         proc updateOutline {this x y} {                                                 ;# coordinates are relative to manager frame
             lifoLabel::pop $global::messenger                                                 ;# remove previous coordinates or size
 
-            if {[set (hidden)]} {                                                              ;# make sure outline is fully visible
+            if {$(hidden)} {                                                                   ;# make sure outline is fully visible
                 stackOutline $this raise
             }
-            set canvas [set ($this,canvas)]
-            set coordinates [$canvas coords [set ($this,item)]]
+            set canvas $($this,canvas)
+            set coordinates [$canvas coords $($this,item)]
             # make sure that pointer stays within canvas boundaries
             set xFrame [lindex $coordinates 0]
             set yFrame [lindex $coordinates 1]
@@ -273,18 +274,18 @@ class canvasWindowManager {
                 set y [expr {$height-$yFrame-1}]
             }
 
-            if {[string length [set ($this,direction)]]==0} {                                                ;# moving, not resizing
-                $canvas move outline [expr {$x-[set (xLast)]}] [expr {$y-[set (yLast)]}]
+            if {[string length $($this,direction)]==0} {                                                     ;# moving, not resizing
+                $canvas move outline [expr {$x-$(xLast)}] [expr {$y-$(yLast)}]
                 lifoLabel::push $global::messenger [$canvas coords outline]               ;# display new coordinates in message area
-                set canvasWindowManager::handles::(xLast) $x                         ;### Tcl BUG: should be set ([xy]Last) $... ###
-                set canvasWindowManager::handles::(yLast) $y
+                set ::canvasWindowManager::handles::(xLast) $x
+                set ::canvasWindowManager::handles::(yLast) $y
                 return
             }
 
             set width [winfo width $widget::($this,path)]
             set height [winfo height $widget::($this,path)]
 
-            switch [set ($this,direction)] {                                                                             ;# resizing
+            switch $($this,direction) {                                                                                  ;# resizing
                 nw - wn {
                     displayOutline $this [expr {$xFrame+$x}] [expr {$yFrame+$y}] [expr {$width-$x}] [expr {$height-$y}]
                 }
@@ -314,23 +315,23 @@ class canvasWindowManager {
 
         proc createOutline {this} {
             # create outline borders (a single frame with no background cannot be used for it hides underlying windows)
-            set canvas [set ($this,canvas)]
+            set canvas $($this,canvas)
             foreach side {top bottom left right} {
                 set frame [frame $canvas.${side}outline -background black]
                 # items are static because there can be only 1 outline at a time
                 set ($side,item) [$canvas create window 0 0 -window $frame -width 0 -height 0 -anchor nw -tags outline]
             }
             stackOutline $this lower                                                  ;# hide outline for now and make it fit widget
-            eval displayOutline $this [$canvas coords [set ($this,item)]]\
+            eval displayOutline $this [$canvas coords $($this,item)]\
                 [winfo width $widget::($this,path)] [winfo height $widget::($this,path)]
         }
 
         proc stackOutline {this order} {                                                      ;# order must be either raise or lower
-            set canvas [set ($this,canvas)]
+            set canvas $($this,canvas)
             foreach side {top bottom left right} {
-                $order [$canvas itemcget [set ($side,item)] -window]
+                $order [$canvas itemcget $($side,item) -window]
             }
-            set (hidden) [string compare $order raise]
+            set ::canvasWindowManager::handles::(hidden) [string compare $order raise]
         }
 
         proc displayOutline {this x y width height} {                                          ;# coordinates are relative to canvas
@@ -338,38 +339,36 @@ class canvasWindowManager {
             set minimum [expr {(2*$composite::($this,-borderwidth))+1}]                ;# make sure managed widget is always visible
             set width [maximum $minimum $width]
             set height [maximum $minimum $height]
-            set canvas [set ($this,canvas)]
-            $canvas coords [set (top,item)] $x $y
-            $canvas coords [set (bottom,item)] $x [expr {$y+$height-1}]
-            $canvas coords [set (left,item)] $x $y
-            $canvas coords [set (right,item)] [expr {$x+$width-1}] $y
-            $canvas itemconfigure [set (top,item)] -width $width
-            $canvas itemconfigure [set (bottom,item)] -width $width
-            $canvas itemconfigure [set (left,item)] -height $height
-            $canvas itemconfigure [set (right,item)] -height $height
+            set canvas $($this,canvas)
+            $canvas coords $(top,item) $x $y
+            $canvas coords $(bottom,item) $x [expr {$y+$height-1}]
+            $canvas coords $(left,item) $x $y
+            $canvas coords $(right,item) [expr {$x+$width-1}] $y
+            $canvas itemconfigure $(top,item) -width $width
+            $canvas itemconfigure $(bottom,item) -width $width
+            $canvas itemconfigure $(left,item) -height $height
+            $canvas itemconfigure $(right,item) -height $height
         }
 
         proc destroyOutline {this} {
-            set canvas [set ($this,canvas)]
+            set canvas $($this,canvas)
             foreach side {top bottom left right} {
-                destroy [$canvas itemcget [set ($side,item)] -window]                                          ;# destroy side frame
+                destroy [$canvas itemcget $($side,item) -window]                                               ;# destroy side frame
                 unset ($side,item)
             }
             $canvas delete outline                                                                              ;# delete side items
         }
 
         proc updateGeometry {this} {                ;# update managed widget position and size according to outline current geometry
-            set canvas [set ($this,canvas)]
-            eval $canvas coords [set ($this,item)] [$canvas coords outline]
-            $canvas itemconfigure [set ($this,item)] -width [$canvas itemcget [set (top,item)] -width]\
-                -height [$canvas itemcget [set (left,item)] -height]
+            set canvas $($this,canvas)
+            eval $canvas coords $($this,item) [$canvas coords outline]
+            $canvas itemconfigure $($this,item) -width [$canvas itemcget $(top,item) -width]\
+                -height [$canvas itemcget $(left,item) -height]
         }
 
         proc getGeometry {this} {                                                         ;# return x, y, width and height as a list
-            set canvas [set ($this,canvas)]
             return [concat\
-                [[set ($this,canvas)] coords [set ($this,item)]]\
-                [winfo width $widget::($this,path)] [winfo height $widget::($this,path)]\
+                [$($this,canvas) coords $($this,item)] [winfo width $widget::($this,path)] [winfo height $widget::($this,path)]\
             ]
         }
 
@@ -378,7 +377,7 @@ class canvasWindowManager {
             if {[string length $composite::($this,-path)]>0} {                                           ;# if managed widget exists
                 raise $composite::($this,-path) $widget::($this,path)                                ;# maintain it just above frame
             }
-            canvasWindowManager::stacked [set ($this,manager)] $composite::($this,-path) [string compare $order lower]
+            canvasWindowManager::stacked $($this,manager) $composite::($this,-path) [string compare $order lower]
         }
 
         proc stackLower {this handles} {                                                ;# invoked by window manager, so no callback
