@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: databar.tcl,v 1.19 1999/03/13 21:35:22 jfontain Exp $}
+set rcsId {$Id: databar.tcl,v 1.20 1999/04/25 12:44:35 jfontain Exp $}
 
 class dataBarChart {
 
@@ -27,9 +27,9 @@ class dataBarChart {
         return [list\
             [list -deletecommand {} {}]\
             [list -draggable draggable Draggable 0 0]\
-            [list -height height Height $configuration::(default,viewer,height)]\
+            [list -height height Height $global::viewerHeight]\
             [list -mode mode Mode normal normal]\
-            [list -width width Width $configuration::(default,viewer,width)]\
+            [list -width width Width $global::viewerWidth]\
         ]
     }
 
