@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datapie.tcl,v 1.35 1999/04/25 12:44:35 jfontain Exp $}
+set rcsId {$Id: datapie.tcl,v 2.3 1999/08/28 11:03:53 jfontain Exp $}
 
 class dataPieChart {
 
@@ -9,28 +9,27 @@ class dataPieChart {
         [new canvas $parentPath -highlightthickness 0 -borderwidth 2] $args
     } viewer {} {
         set path $widget::($this,path)
-        set dataPieChart::($this,slices) {}
+        set ($this,slices) {}
         viewer::setupDropSite $this $path                                                            ;# allow dropping of data cells
 
         composite::complete $this
 
         # wait till completion to create pie since -selectable option is not dynamically settable
         set padding [$path cget -borderwidth]
-        set dataPieChart::($this,pie) [new pie $path $padding $padding\
+        set ($this,pie) [new pie $path $padding $padding\
             -title {} -thickness $thickness -selectable $composite::($this,-draggable)\
             -labeler [new piePeripheralLabeler $path\
                 -font $font::(mediumNormal) -smallfont $font::(smallNormal) -widestvaluetext {00.0 %}\
             ]\
         ]
         set padding [expr {2*$padding}]                                      ;# width and height are diminished by twice the padding
-        bind $path <Configure>\
-            "switched::configure $dataPieChart::($this,pie) -width \[expr {%w-$padding}\] -height \[expr {%h-$padding}\]"
+        bind $path <Configure> "switched::configure $($this,pie) -width \[expr {%w-$padding}\] -height \[expr {%h-$padding}\]"
     }
 
     proc ~dataPieChart {this} {
-        delete $dataPieChart::($this,pie)
-        if {[info exists dataPieChart::($this,drag)]} {
-            delete $dataPieChart::($this,drag)
+        delete $($this,pie)
+        if {[info exists ($this,drag)]} {
+            delete $($this,drag)
         }
         if {[string length $composite::($this,-deletecommand)]>0} {
             uplevel #0 $composite::($this,-deletecommand)                                   ;# always invoke command at global level
@@ -54,9 +53,9 @@ class dataPieChart {
             error {option -draggable cannot be set dynamically}
         }
         if {!$value} return                                                                                           ;# no dragging
-        set dataPieChart::($this,drag) [new dragSite -path $widget::($this,path) -validcommand "dataPieChart::validateDrag $this"]
-        dragSite::provide $dataPieChart::($this,drag) OBJECTS "dataPieChart::dragData $this"
-        dragSite::provide $dataPieChart::($this,drag) DATACELLS "dataPieChart::dragData $this"
+        set ($this,drag) [new dragSite -path $widget::($this,path) -validcommand "dataPieChart::validateDrag $this"]
+        dragSite::provide $($this,drag) OBJECTS "dataPieChart::dragData $this"
+        dragSite::provide $($this,drag) DATACELLS "dataPieChart::dragData $this"
     }
 
     foreach option {-height -width} {
@@ -64,12 +63,12 @@ class dataPieChart {
     }
 
     proc dragData {this format} {
-        set slices [slice::selected $dataPieChart::($this,pie)]
+        set slices [slice::selected $($this,pie)]
         switch $format {
             OBJECTS {
                 if {[llength $slices]>0} {
                     return $slices                                                        ;# return selected slices if there are any
-                } elseif {[llength $dataPieChart::($this,slices)]==0} {
+                } elseif {[llength $($this,slices)]==0} {
                     return $this                                                       ;# return pie itself if it contains no slices
                 } else {
                     return {}                                                                            ;# return nothing otherwise
@@ -82,13 +81,11 @@ class dataPieChart {
     }
 
     proc validateDrag {this x y} {
-        if {[llength $dataPieChart::($this,slices)]==0} {
+        if {[llength $($this,slices)]==0} {
             return 1                                                                                   ;# allow drag of empty viewer
         }
         # allow dragging if only from a selected slice
-        return [expr {\
-            [lsearch -exact [slice::selected $dataPieChart::($this,pie)] [slice::current $dataPieChart::($this,pie)]]>=0\
-        }]
+        return [expr {[lsearch -exact [slice::selected $($this,pie)] [slice::current $($this,pie)]]>=0}]
     }
 
     proc supportedTypes {this} {
@@ -98,20 +95,20 @@ class dataPieChart {
     proc monitorCell {this array row column} {
         viewer::registerTrace $this $array
         set cell ${array}($row,$column)
-        if {[lsearch -exact [cellsFromSlices $this $dataPieChart::($this,slices)] $cell]>=0} return        ;# already charted, abort
-        set slice [new slice $dataPieChart::($this,pie) [viewer::label $array $row $column]]
-        lappend dataPieChart::($this,slices) $slice
+        if {[lsearch -exact [cellsFromSlices $this $($this,slices)] $cell]>=0} return                      ;# already charted, abort
+        set slice [new slice $($this,pie) [viewer::label $array $row $column]]
+        lappend ($this,slices) $slice
         switched::configure $slice -deletecommand "dataPieChart::deletedSlice $this $array $slice"  ;# keep track of slice existence
-        set dataPieChart::($this,cell,$slice) $cell
+        set ($this,cell,$slice) $cell
     }
 
     proc update {this array args} {                              ;# update display using cells data. ignore eventual trace arguments
-        set cells [cellsFromSlices $this $dataPieChart::($this,slices)]
+        set cells [cellsFromSlices $this $($this,slices)]
         set sum 0.0                                                                             ;# force floating point calculations
         foreach cell $cells {
             catch {set sum [expr {$sum+[set $cell]}]}                              ;# ignore errors as data cell may no longer exist
         }
-        foreach slice $dataPieChart::($this,slices) cell $cells {
+        foreach slice $($this,slices) cell $cells {
             if {[catch {set $cell} value]||($sum==0)} {                            ;# handle invalid cells and divide by zero errors
                 slice::update $slice 0 ?
             } else {
@@ -123,20 +120,20 @@ class dataPieChart {
 
     proc deletedSlice {this array slice} {
         viewer::unregisterTrace $this $array                                          ;# trace may no longer be needed on this array
-        ldelete dataPieChart::($this,slices) $slice
-        unset dataPieChart::($this,cell,$slice)
+        ldelete ($this,slices) $slice
+        unset ($this,cell,$slice)
     }
 
     proc cellsFromSlices {this slices} {
         set cells {}
         foreach slice $slices {
-            lappend cells $dataPieChart::($this,cell,$slice)
+            lappend cells $($this,cell,$slice)
         }
         return $cells
     }
 
     proc cells {this} {
-        return [cellsFromSlices $this $dataPieChart::($this,slices)]
+        return [cellsFromSlices $this $($this,slices)]
     }
 }
 
@@ -153,8 +150,8 @@ class dataPieChart {
         }
 
         proc ~slice {this} {
-            pie::deleteSlice [set ($this,pie)] [set ($this,slice)]
-            unset (this,[set ($this,slice)])
+            pie::deleteSlice $($this,pie) $($this,slice)
+            unset (this,$($this,slice))
             if {[string length $switched::($this,-deletecommand)]>0} {
                 uplevel #0 $switched::($this,-deletecommand)                                ;# always invoke command at global level
             }
@@ -169,13 +166,13 @@ class dataPieChart {
         proc set-deletecommand {this value} {}                                                   ;# data is stored at switched level
 
         proc update {this value string} {
-            pie::sizeSlice [set ($this,pie)] [set ($this,slice)] $value $string
+            pie::sizeSlice $($this,pie) $($this,slice) $value $string
         }
 
         proc selected {pie} {                                                            ;# return selected slices for specified pie
             set list {}
             foreach slice [pie::selectedSlices $pie] {
-                lappend list [set (this,$slice)]
+                lappend list $(this,$slice)
             }
             return $list
         }
@@ -185,7 +182,7 @@ class dataPieChart {
             if {$slice==0} {
                 return 0                                                                                         ;# no current slice
             } else {
-                return [set (this,$slice)]                                                 ;# return object corresponding with slice
+                return $(this,$slice)                                                      ;# return object corresponding with slice
             }            
         }
 
