@@ -1,18 +1,17 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.58 1999/05/01 19:05:35 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 2.2 1999/08/28 10:48:16 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
-    set dataTable::(list) {}
-
-    set dataTable::(scrollbarBorderWidth) [expr {$widget::(default,ScrollbarBorderWidth)==0?0:1}]
-    set dataTable::(scrollbarWidth) [expr {2*$widget::(default,ScrollbarWidth)/3}]
+    set ::dataTable::(list) {}
+    set ::dataTable::(scrollbarBorderWidth) [expr {$widget::(default,ScrollbarBorderWidth)==0?0:1}]
+    set ::dataTable::(scrollbarWidth) [expr {2*$widget::(default,ScrollbarWidth)/3}]
 
     proc dataTable {this parentPath args} composite {
         [new scroll table $parentPath\
-            -scrollbarwidth $dataTable::(scrollbarWidth) -scrollbarelementborderwidth $dataTable::(scrollbarBorderWidth)\
+            -scrollbarwidth $(scrollbarWidth) -scrollbarelementborderwidth $(scrollbarBorderWidth)\
             -width $global::viewerWidth -height $global::viewerHeight\
         ]
         $args
@@ -33,10 +32,10 @@ class dataTable {                       ;# module data view in the form of a tab
         bind $path <ButtonPress-1> "dataTable::buttonPress $this %x %y"
         bind $path <Button1-Motion> "if \$dataTable::($this,columnBorderHit) {%W border dragto %x %y}"
 
-        set dataTable::($this,sortOrder) increasing
-        set dataTable::($this,tablePath) $path
+        set ($this,sortOrder) increasing
+        set ($this,tablePath) $path
 
-        lappend dataTable::(list) $this
+        lappend ::dataTable::(list) $this
 
         composite::complete $this
         setupDataView $this                                              ;# wait till -data and eventually -view options are defined
@@ -49,16 +48,16 @@ class dataTable {                       ;# module data view in the form of a tab
             setTrace $this 0                                                                                         ;# remove trace
         }
         catch {unset ${this}data}                                                                      ;# eventually free table data
-        if {[info exists dataTable::($this,arrow)]} {
-            eval delete $dataTable::($this,arrow) $dataTable::($this,tips)
+        if {[info exists ($this,arrow)]} {
+            eval delete $($this,arrow) $($this,tips)
         }
-        if {[info exists dataTable::($this,drag)]} {
-            delete $dataTable::($this,drag)
+        if {[info exists ($this,drag)]} {
+            delete $($this,drag)
         }
-        if {[info exists dataTable::($this,selector)]} {                            ;# selector may not exist if dragging disallowed
-            delete $dataTable::($this,selector)
+        if {[info exists ($this,selector)]} {                                       ;# selector may not exist if dragging disallowed
+            delete $($this,selector)
         }
-        ldelete dataTable::(list) $this
+        ldelete ::dataTable::(list) $this
     }
 
     proc options {this} {
@@ -79,8 +78,8 @@ class dataTable {                       ;# module data view in the form of a tab
     proc set-titlefont {this value} {
         if {[string length $composite::($this,-data)]==0} return                                         ;# nothing to do if no data
 
-        set path $dataTable::($this,tablePath)
-        for {set column 0} {$column<[llength $dataTable::($this,dataColumns)]} {incr column} {
+        set path $($this,tablePath)
+        for {set column 0} {$column<[llength $($this,dataColumns)]} {incr column} {
             $path.$column.label configure -font $value
         }
     }
@@ -99,11 +98,11 @@ class dataTable {                       ;# module data view in the form of a tab
             error {option -draggable cannot be set dynamically}
         }
         if {!$value} return                                                                                           ;# no dragging
-        set path $dataTable::($this,tablePath)
-        set dataTable::($this,drag) [new dragSite -path $path -validcommand "dataTable::validateDrag $this"]
-        dragSite::provide $dataTable::($this,drag) DATACELLS "dataTable::dragData $this"
+        set path $($this,tablePath)
+        set ($this,drag) [new dragSite -path $path -validcommand "dataTable::validateDrag $this"]
+        dragSite::provide $($this,drag) DATACELLS "dataTable::dragData $this"
 
-        set dataTable::($this,selector) [new tableSelector -selectcommand "dataTable::setCellsState $this"]
+        set ($this,selector) [new tableSelector -selectcommand "dataTable::setCellsState $this"]
         bind $path <ButtonRelease-1> "dataTable::buttonRelease $this %x %y"
         bind $path <Control-ButtonRelease-1> "dataTable::toggleSelection $this %x %y"
         bind $path <Shift-ButtonRelease-1> "dataTable::extendSelection $this %x %y"
@@ -120,32 +119,32 @@ class dataTable {                       ;# module data view in the form of a tab
     }
 
     proc buttonRelease {this x y} {
-        if {!$dataTable::($this,columnBorderHit)} {                        ;# if column was resized, do not interfere with selection
-            set number [expr {[$dataTable::($this,tablePath) cget -rows]-1}]                        ;# calculate number of data rows
+        if {!$($this,columnBorderHit)} {                                   ;# if column was resized, do not interfere with selection
+            set number [expr {[$($this,tablePath) cget -rows]-1}]                                   ;# calculate number of data rows
             if {$number==0} return
-            scan [$dataTable::($this,tablePath) index @$x,$y] %d,%d row column
+            scan [$($this,tablePath) index @$x,$y] %d,%d row column
             if {$row<0} return                                                                           ;# title row, nothing to do
-            if {[info exists dataTable::($this,selector)]} {
-                selector::select $dataTable::($this,selector) $row,$column
+            if {[info exists ($this,selector)]} {
+                selector::select $($this,selector) $row,$column
             }
         }
-        unset dataTable::($this,columnBorderHit)
+        unset ($this,columnBorderHit)
     }
 
     proc columnSort {this column} {                        ;# sort table rows using the column that the user selected as a reference
-        if {$column==$dataTable::($this,sortColumn)} {                                                       ;# sort the same column
-            if {[string compare $dataTable::($this,sortOrder) increasing]==0} {                                ;# but toggle sorting
-                set dataTable::($this,sortOrder) decreasing
+        if {$column==$($this,sortColumn)} {                                                                  ;# sort the same column
+            if {[string equal $($this,sortOrder) increasing]} {                                                ;# but toggle sorting
+                set ($this,sortOrder) decreasing
             } else {
-                set dataTable::($this,sortOrder) increasing
+                set ($this,sortOrder) increasing
             }
         } else {                                                                ;# sort for the first time or for a different column
-            set dataTable::($this,sortColumn) $column
-            set dataTable::($this,sortOrder) increasing
+            set ($this,sortColumn) $column
+            set ($this,sortOrder) increasing
         }
         # deselect all cells since reordering rows renders selection meaningless
-        if {[info exists dataTable::($this,selector)]} {
-            selector::clear $dataTable::($this,selector)
+        if {[info exists ($this,selector)]} {
+            selector::clear $($this,selector)
         }
         update $this                                                                                     ;# update table immediately
     }
@@ -154,13 +153,13 @@ class dataTable {                       ;# module data view in the form of a tab
         variable ${this}data
         upvar #0 $composite::($this,-data) data                                              ;# data must be visible at global level
 
-        set path $dataTable::($this,tablePath)
+        set path $($this,tablePath)
 
         set cursor [$path cget -cursor]                                                                               ;# save cursor
         $path configure -cursor watch                                                                  ;# show user that we are busy
         ::update idletasks
 
-        set sortColumn $dataTable::($this,sortColumn)
+        set sortColumn $($this,sortColumn)
         set lists {}
         if {[regexp {^integer|real$} $data($sortColumn,type)]} {                                                     ;# numeric type
             foreach name [array names data *,$sortColumn] {
@@ -178,10 +177,10 @@ class dataTable {                       ;# module data view in the form of a tab
             }
         }
         # sort data rows according to sort column (column numbering is identical for table data and source data)
-        set lists [lsort -$dataTable::($this,sortOrder) -$data($sortColumn,type) -index 1 $lists]
+        set lists [lsort -$($this,sortOrder) -$data($sortColumn,type) -index 1 $lists]
 
-        if {[info exists dataTable::($this,selector)]} {
-            set selector $dataTable::($this,selector)
+        if {[info exists ($this,selector)]} {
+            set selector $($this,selector)
         }
         set changed 0                                                        ;# keep track of whether any rows were added or removed
         set row 0
@@ -193,7 +192,7 @@ class dataTable {                       ;# module data view in the form of a tab
             }
             set ${this}data($row,dataRow) $dataRow                                        ;# keep track of table / data rows mapping
             set column 0
-            foreach dataColumn $dataTable::($this,dataColumns) {
+            foreach dataColumn $($this,dataColumns) {
                 set ${this}data($row,$column) $data($dataRow,$dataColumn)
                 incr column
             }
@@ -201,7 +200,7 @@ class dataTable {                       ;# module data view in the form of a tab
         }
         $path configure -rows [expr {$row+1}]                                           ;# fit to data (take into account title row)
 
-        set columns [llength $dataTable::($this,dataColumns)]
+        set columns [llength $($this,dataColumns)]
 
         if {[llength $rows]>0} {                                                                      ;# one or more rows were added
             set changed 1
@@ -249,7 +248,7 @@ class dataTable {                       ;# module data view in the form of a tab
 
         set data $composite::($this,-data)
         set list {}
-        foreach cell [selector::selected $dataTable::($this,selector)] {
+        foreach cell [selector::selected $($this,selector)] {
             scan $cell %d,%d row column
             # data cell format is array(row,column)
             lappend list ${data}([set ${this}data($row,dataRow)],[set ${this}data($column,dataColumn)])
@@ -258,63 +257,61 @@ class dataTable {                       ;# module data view in the form of a tab
     }
 
     proc validateDrag {this x y} {
-        if {$dataTable::($this,columnBorderHit)} {
+        if {$($this,columnBorderHit)} {
             return 0                                                                              ;# resizing a column: prevent drag
         }
-        if {[$dataTable::($this,tablePath) cget -rows]<=1} {
+        if {[$($this,tablePath) cget -rows]<=1} {
             return 1                                                  ;# allow dragging of empty table (with eventually 1 title row)
         }
         # allow dragging only from a selected cell
-        return [expr\
-            {[lsearch -exact [selector::selected $dataTable::($this,selector)] [$dataTable::($this,tablePath) index @$x,$y]]>=0}\
-        ]
+        return [expr {[lsearch -exact [selector::selected $($this,selector)] [$($this,tablePath) index @$x,$y]]>=0}]
     }
 
     proc setCellsState {this cells select} {
         if {$select} {
-            eval $dataTable::($this,tablePath) tag cell select $cells
+            eval $($this,tablePath) tag cell select $cells
         } else {
-            eval $dataTable::($this,tablePath) tag cell {{}} $cells
+            eval $($this,tablePath) tag cell {{}} $cells
         }
     }
 
     proc toggleSelection {this x y} {
-        set cell [$dataTable::($this,tablePath) index @$x,$y]
+        set cell [$($this,tablePath) index @$x,$y]
         scan $cell %d row
         if {$row<0} return                                                                         ;# prevent selection on title row
-        selector::toggle $dataTable::($this,selector) $cell
+        selector::toggle $($this,selector) $cell
     }
 
     proc extendSelection {this x y} {
-        set cell [$dataTable::($this,tablePath) index @$x,$y]
+        set cell [$($this,tablePath) index @$x,$y]
         scan $cell %d row
         if {$row<0} return                                                                         ;# prevent selection on title row
-        selector::extend $dataTable::($this,selector) $cell
+        selector::extend $($this,selector) $cell
     }
 
     proc updateSortingArrow {this column} {
-        set path $widget::($dataTable::($this,arrow),path)
+        set path $widget::($($this,arrow),path)
 
-        set label $dataTable::($this,tablePath).$column.label      ;# copy title label bindings for contextual help and mouse action
+        set label $($this,tablePath).$column.label                 ;# copy title label bindings for contextual help and mouse action
         foreach event {<Enter> <Leave> <ButtonRelease-1>} {
             bind $path $event [bind $label $event]
         }
-        if {[string compare $dataTable::($this,sortOrder) increasing]==0} {
-            widget::configure $dataTable::($this,arrow) -direction down
+        if {[string equal $($this,sortOrder) increasing]} {
+            widget::configure $($this,arrow) -direction down
         } else {
-            widget::configure $dataTable::($this,arrow) -direction up
+            widget::configure $($this,arrow) -direction up
         }
         # place arrow in sorted column title frame on the right side of label
-        place $path -in $dataTable::($this,tablePath).$column -anchor e -relx 1 -rely 0.5 -relheight 1
+        place $path -in $($this,tablePath).$column -anchor e -relx 1 -rely 0.5 -relheight 1
     }
 
     proc createTitles {this} {
         upvar #0 $composite::($this,-data) data                                              ;# data must be visible at global level
 
-        set path $dataTable::($this,tablePath)
+        set path $($this,tablePath)
         set font $composite::($this,-titlefont)
         set column 0
-        foreach dataColumn $dataTable::($this,dataColumns) {
+        foreach dataColumn $($this,dataColumns) {
             # create table title labels in separate windows
             set frame [frame $path.$column]                       ;# use a frame as a container for label and eventual sorting arrow
             # force default arrow cursor as column resizing cursor sticks when moving across columns
@@ -325,7 +322,7 @@ class dataTable {                       ;# module data view in the form of a tab
             # setup context sensitive help on titles using help strings from module data
             bind $label <Enter> "lifoLabel::push $global::messenger [list $data($dataColumn,message)]"
             bind $label <Leave> "lifoLabel::pop $global::messenger"
-            lappend dataTable::($this,tips) [new widgetTip -path $label -text {click to toggle sort}]
+            lappend ($this,tips) [new widgetTip -path $label -text {click to toggle sort}]
             incr column
         }
         $path configure -cols $column                                                              ;# fit table to number of columns
@@ -335,15 +332,15 @@ class dataTable {                       ;# module data view in the form of a tab
         widget::configure $arrow -disabledforeground [widget::cget $arrow -foreground]                   ;# make arrow fully visible
         # force default arrow cursor as column resizing cursor sticks when moving across columns
         $widget::($arrow,path) configure -cursor top_left_arrow
-        lappend dataTable::($this,tips) [new widgetTip -path $widget::($arrow,path) -text {click to toggle sort}]
-        set dataTable::($this,arrow) $arrow
+        lappend ($this,tips) [new widgetTip -path $widget::($arrow,path) -text {click to toggle sort}]
+        set ($this,arrow) $arrow
     }
 
     proc buttonPress {this x y} {
-        foreach {row column} [$dataTable::($this,tablePath) border mark $x $y] {}
+        foreach {row column} [$($this,tablePath) border mark $x $y] {}
         # do not allow resizing with rightmost column edge
-        set dataTable::($this,columnBorderHit)\
-            [expr {[info exists column]&&([string length $column]>0)&&($column<([$dataTable::($this,tablePath) cget -cols]-1))}]
+        set ($this,columnBorderHit)\
+            [expr {[info exists column]&&([string length $column]>0)&&($column<([$($this,tablePath) cget -cols]-1))}]
     }
 
     proc setupDataView {this} {
@@ -363,16 +360,16 @@ class dataTable {                       ;# module data view in the form of a tab
                 }
             }
         }
-        set dataTable::($this,dataColumns) [lsort -integer $columns]                                     ;# then sort and store them
-        set dataTable::($this,sortColumn) [lindex $data(sort) 0]
-        if {[lsearch -exact $columns $dataTable::($this,sortColumn)]<0} {
-            error "sort column $dataTable::($this,sortColumn) is not visible"
+        set ($this,dataColumns) [lsort -integer $columns]                                                ;# then sort and store them
+        set ($this,sortColumn) [lindex $data(sort) 0]
+        if {[lsearch -exact $columns $($this,sortColumn)]<0} {
+            error "sort column $($this,sortColumn) is not visible"
         }
-        set dataTable::($this,sortOrder) [lindex $data(sort) 1]
+        set ($this,sortOrder) [lindex $data(sort) 1]
         set column 0
-        foreach dataColumn $dataTable::($this,dataColumns) {                                   ;# store table / data columns mapping
+        foreach dataColumn $($this,dataColumns) {                                              ;# store table / data columns mapping
             set ${this}data($column,dataColumn) $dataColumn
-            if {$dataColumn==$dataTable::($this,sortColumn)} {
+            if {$dataColumn==$($this,sortColumn)} {
                 set sortColumnIndex $column
             }
             incr column
@@ -384,7 +381,7 @@ class dataTable {                       ;# module data view in the form of a tab
     }
 
     proc updateColumnWidths {this} {                                                        ;# best apply widths to existing columns
-        set path $dataTable::($this,tablePath)
+        set path $($this,tablePath)
         set index 0
         foreach width $composite::($this,-columnwidths) {
             $path width $index $width
@@ -393,7 +390,7 @@ class dataTable {                       ;# module data view in the form of a tab
     }
 
     proc initializationConfiguration {this} {
-        set path $dataTable::($this,tablePath)
+        set path $($this,tablePath)
         for {set column 0} {$column<[$path cget -cols]} {incr column} {
             lappend widths [$path width $column]
         }
@@ -413,14 +410,14 @@ class dataTable {                       ;# module data view in the form of a tab
         upvar #0 $composite::($this,-data) data
 
         set column -1
-        set path $dataTable::($this,tablePath)
-        foreach dataColumn $dataTable::($this,dataColumns) {
+        set path $($this,tablePath)
+        foreach dataColumn $($this,dataColumns) {
             incr column
             if {[catch {set anchor $data($dataColumn,anchor)}]} continue      ;# no anchor for this column, default (center) is used
             if {![regexp {^center|left|right$} $anchor]} {
                 error "bad anchor value \"$anchor\": must be center, left or right"
             }
-            if {[string compare $anchor center]==0} continue                  ;# nothing to do as center is column anchoring default
+            if {[string equal $anchor center]} continue                       ;# nothing to do as center is column anchoring default
             if {![$path tag exists $anchor]} {        ;# create anchor tag as needed and use valid anchor values (see above) as name
                 array set convert {left w right e}
                 $path tag configure $anchor -anchor $convert($anchor)
