@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: dialog.tcl,v 1.15 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: dialog.tcl,v 2.1 1999/08/27 21:05:05 jfontain Exp $}
 
 class dialogBox {}
 
@@ -122,16 +122,16 @@ proc dialogBox::set-transient {this value} {
 
 proc dialogBox::display {this path} {                                                ;# must be invoked for dialog box to be visible
     if {[string length $path]==0} {                                                           ;# undisplay, remove related resources
-        if {[info exists dialogBox::($this,displayed)]} {
-            grid forget $dialogBox::($this,displayed)
-            unset dialogBox::($this,displayed)
+        if {[info exists ($this,displayed)]} {
+            grid forget $($this,displayed)
+            unset ($this,displayed)
         }
         return
     }
-    if {[info exists dialogBox::($this,displayed)]} {
-        error "a widget ($dialogBox::($this,displayed)) is already displayed"
+    if {[info exists ($this,displayed)]} {
+        error "a widget ($($this,displayed)) is already displayed"
     }
-    set dialogBox::($this,displayed) $path
+    set ($this,displayed) $path
     grid $path -in $widget::($this,path) -column 0 -row 0 -sticky nsew -pady 3
     place $this
 }
