@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: diskstats.tcl,v 1.13 1999/08/01 12:59:55 jfontain Exp $}
+set rcsId {$Id: diskstats.tcl,v 2.1 1999/08/27 20:19:00 jfontain Exp $}
 
 package provide diskstats 1.1
 package require filesystem
@@ -91,7 +91,7 @@ namespace eval diskstats {
                             regexp {Vendor:(.*)Model:(.*)Rev:(.*)$} [gets $file] dummy vendor model revision
                             regexp {Type:(.*)ANSI SCSI revision:} [gets $file] dummy media
                             set media [string trim $media]
-                            if {[string compare $media Direct-Access]!=0} continue  ;# not a disk therefore not listed in partitions
+                            if {![string equal $media Direct-Access]} continue      ;# not a disk therefore not listed in partitions
                             if {$diskNumber==$nextSCSINumber} {            ;# assume that SCSI devices are listed in discovery order
                                 set data($index,6) $media
                                 set data($index,8) "[string trim $vendor], [string trim $model], [string trim $revision]"
@@ -118,7 +118,7 @@ namespace eval diskstats {
         }
 
         seek $statistics 0                                                                   ;# always rewind before retrieving data
-        gets $statistics; gets $statistics                                                                     ;# skip first 2 lines
+        while {![string match disk* [gets $statistics]]} {}     ;# forward to first disk entry line (in case there are several CPUs)
         scan [gets $statistics] {disk_rio %u %u %u %u} data(0,1) data(1,1) data(2,1) data(3,1)
         scan [gets $statistics] {disk_wio %u %u %u %u} data(0,2) data(1,2) data(2,2) data(3,2)
         scan [gets $statistics] {disk_rblk %u %u %u %u} data(0,3) data(1,3) data(2,3) data(3,3)
