@@ -1,21 +1,21 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: drop.tcl,v 1.14 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: drop.tcl,v 2.2 1999/08/28 10:55:13 jfontain Exp $}
 
 class dropSite {
-    set dropSite::(list) {}                                                                            ;# initialize list of objects
+    set ::dropSite::(list) {}                                                                          ;# initialize list of objects
 
     proc dropSite {this args} switched {$args} {
-        lappend dropSite::(list) $this                                               ;# manage a list of drop sites for drop regions
+        lappend ::dropSite::(list) $this                                             ;# manage a list of drop sites for drop regions
         switched::complete $this
     }
 
     proc ~dropSite {this} {
-        set index [lsearch -exact $dropSite::(list) $this]                                                  ;# remove self from list
-        set dropSite::(list) [lreplace $dropSite::(list) $index $index]
+        set index [lsearch -exact $(list) $this]                                                            ;# remove self from list
+        set ::dropSite::(list) [lreplace $(list) $index $index]
         if {[string length $switched::($this,-path)]>0} {                                        ;# if there was an actual drop site
-            delete $dropSite::($this,bindings)                                                               ;# remove drop bindings
+            delete $($this,bindings)                                                                         ;# remove drop bindings
         }
     }
 
@@ -38,10 +38,9 @@ class dropSite {
         if {![winfo exists $value]} {
             error "invalid widget: \"$value\""
         }
-        set dropSite::($this,bindings) [new bindings $value end]                          ;# do not interfere with existing bindings
-        set dropSite::($this,visible) 1                                                                        ;# monitor visibility
-        bindings::set $dropSite::($this,bindings) <Visibility>\
-            "set dropSite::($this,visible) \[string compare %s VisibilityFullyObscured\]"
+        set ($this,bindings) [new bindings $value end]                                    ;# do not interfere with existing bindings
+        set ($this,visible) 1                                                                                  ;# monitor visibility
+        bindings::set $($this,bindings) <Visibility> "set ::dropSite::($this,visible) \[string compare %s VisibilityFullyObscured\]"
     }
 
     proc dropped {this} {
@@ -55,10 +54,10 @@ class dropSite {
     proc regions {formats} {                                             ;# return a list of drop sites with compatible data formats
         # update was invoked here to make sure visibility and coordinates are correct, but it interferences with events in drag code
         set regions {}
-        foreach site $dropSite::(list) {
+        foreach site $(list) {
             if {[catch {winfo viewable $switched::($site,-path)} viewable]} continue    ;# check if viewable, path may also be empty
             # check that drop site is at least partly visible and not iconified
-            if {!$viewable||!$dropSite::($site,visible)} continue
+            if {!$viewable||!$($site,visible)} continue
             foreach format $switched::($site,-formats) {
                 if {[lsearch -exact $formats $format]>=0} {
                     set path $switched::($site,-path)
