@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: gui.tcl,v 1.19 1999/07/18 15:49:25 jfontain Exp $}
+set rcsId {$Id: gui.tcl,v 1.21 1999/08/08 18:30:17 jfontain Exp $}
 
 proc updateTitle {} {                                                          ;# show modules and poll time or mode in window title
     if {[llength $global::pollTimes]==0} {
@@ -35,6 +35,8 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
         menuContextHelp::set $global::fileMenuContextHelper [incr index(file)] $string
     }
 
+    $menu.file add separator
+    incr index(file)
     $menu.file add command -label Exit -command exit -underline 1 -accelerator Ctrl+Q
     menuContextHelp::set $global::fileMenuContextHelper [incr index(file)] {close main window and exit program}
     bind $parentPath <Control-q> exit
@@ -42,11 +44,14 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
     if {!$readOnly} {
         $menu add cascade -label Edit -menu [menu $menu.edit -tearoff 0] -underline 0
         set help(edit) [new menuContextHelp $menu.edit]
-        menuContextHelp::set $help(bar) [incr index(bar)] {content editing and preferences}
+        menuContextHelp::set $help(bar) [incr index(bar)] {content editing, configuration and preferences}
+
+        $menu.edit add command -label {Configuration...} -command {configuration::edit 0} -underline 0
+        menuContextHelp::set $help(edit) 0 {edit current configuration}
 
         $menu.edit add cascade -label New -menu [menu $menu.edit.new -tearoff 0] -underline 0
         set help(new) [new menuContextHelp $menu.edit.new]
-        menuContextHelp::set $help(edit) 0 {create empty data viewers}
+        menuContextHelp::set $help(edit) 1 {create empty data viewers}
 
         $menu.edit.new add command -label {Graph Chart...} -underline 0\
             -command "createCellsViewer dataGraph {} 1 $global::static \$global::pollTime"
@@ -79,8 +84,9 @@ proc createMenuWidget {parentPath readOnly includePollTime} {
         $menu.edit.new add command -label {Free Text...} -underline 0 -command "createCellsViewer freeText {} 1 $global::static"
         menuContextHelp::set $help(new) 7 {create an empty free text data viewer}
 
-        $menu.edit add command -label {Preferences...} -command preferences::edit -underline 0
-        menuContextHelp::set $help(edit) 1 {edit preferences and configuration}
+        $menu.edit add separator
+        $menu.edit add command -label {Preferences...} -command {configuration::edit 1} -underline 0
+        menuContextHelp::set $help(edit) 3 {edit application-wide preferences}
     }
 
     if {!$readOnly&&$includePollTime} {
