@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: html.tcl,v 1.25 1999/03/08 18:18:52 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.26 1999/08/02 20:23:01 jfontain Exp $}
 
 # use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
@@ -38,12 +38,10 @@ proc HMlink_callback {widget reference} {
 }
 
 proc HMset_image {widget label source} {                                                          ;# supply image handling procedure
-    if {\
-        [catch {image create photo -file $source} image]&&\
-        [catch {image create photo -file [file join $::widgetHTMLDirectory($widget) $source]} image]\
-    } return                                                             ;# local directory and widget directory searched and failed
-    bind $label <Destroy> "image delete $image"                      ;# setup binding so that image is deleted as label is destroyed
-    HMgot_image $label $image                                                               ;# got the image for the specified label
+    if {![catch {image create photo -file $source} image]} {
+        bind $label <Destroy> "image delete $image"                  ;# setup binding so that image is deleted as label is destroyed
+        HMgot_image $label $image                                                           ;# got the image for the specified label
+    }
 }
 
 proc customHMTLConfiguration {path} {                                             ;# make HTML text widget behave more like Netscape
@@ -96,10 +94,6 @@ proc generalHelpWindow {} {
 
     set htmlHelpDataText $composite::($widget,scrolled,path)                                      ;# now setup and display help text
 
-    # use rpm documentation directory for images repository
-    set ::widgetHTMLDirectory($htmlHelpDataText) /usr/doc/moodss-$global::applicationVersion
-    bind $htmlHelpDataText <Destroy> "unset ::widgetHTMLDirectory($htmlHelpDataText)"
-
     $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
     update idletasks
 
@@ -107,7 +101,10 @@ proc generalHelpWindow {} {
     customHMTLConfiguration $htmlHelpDataText
 
     $htmlHelpDataText configure -state normal
+    set current [pwd]                  ;# temporarily change to documentation directory so that inline images are properly displayed
+    cd $::global::documentationDirectory
     HMparse_html $::htmlHelpData "HMrender $htmlHelpDataText"
+    cd $current
     if {![winfo exists .topHelp]} return                            ;# user may have destroyed the window through the window manager
     $htmlHelpDataText configure -state disabled
     HMset_state $htmlHelpDataText -stop 1                                                    ;# stop rendering previous page if busy
@@ -133,10 +130,6 @@ proc moduleHelpWindow {name} {
 
     set htmlHelpDataText $composite::($widget,scrolled,path)                                          ;# setup and display help text
 
-    # use module directory for images repository
-    set ::widgetHTMLDirectory($htmlHelpDataText) $::packageDirectory($name)
-    bind $htmlHelpDataText <Destroy> "unset ::widgetHTMLDirectory($htmlHelpDataText)"
-
     $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
     update idletasks
 
@@ -144,7 +137,10 @@ proc moduleHelpWindow {name} {
     customHMTLConfiguration $htmlHelpDataText
 
     $htmlHelpDataText configure -state normal
+    set current [pwd]
+    cd $::packageDirectory($name)             ;# temporarily change to module directory so that inline images are properly displayed
     HMparse_html [modules::helpHTMLData $name] "HMrender $htmlHelpDataText"
+    cd $current
     if {![winfo exists .topHelp]} return                            ;# user may have destroyed the window through the window manager
     $htmlHelpDataText configure -state disabled
     HMset_state $htmlHelpDataText -stop 1                                                    ;# stop rendering previous page if busy
