@@ -178,6 +178,8 @@ preferences setting.
 <p>Versions 7.99 and up support concurrent instances of the same module.
 <p>Versions 8.1 and up support configuration settings per dashboard, with
 a user interface similar to the preferences interface.
+<p>Versions 9.0 and up are only compatible with Tcl/Tk versions 8.2 and
+above.
 <p>Since module data access is entirely customizable (through C code, Tcl,
 HTTP, ...) and since several modules can be loaded at once, applications
 for moodss become limitless. For example, comparing a remote database server
@@ -202,25 +204,25 @@ the terms described in the COPYRIGHT file or use the main window Help Copyright
 menu for more information.
 <h3>
 <a NAME="required"></a>3. Required software</h3>
-If you are using a Linux Redhat system (5.1 or above), then use the moodss
-rpm file (available (starting with 4.4) at <a href="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</a>)
-for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
-file for more information). You are then all set for using the included
-Linux modules or develop your own modules.
+If you are using a Linux Redhat system (6.0 or above), then use the moodss
+rpm file (available at <a href="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</a>)
+for installation. It requires the tcl, tk, blt and tktable rpms also available
+at the same location (see INSTALL file for more information). You are then
+all set for using the included Linux modules or develop your own modules.
 <p><b><i>Unless you want to work on the moodss source code (not the modules),
 you can skip the rest of this section.</i></b>
-<p>For the current version (8.1), the following packages must be installed
+<p>For the current version (9.0), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <ul>
 <li>
-Tcl/Tk version 8.0 or above (at <a href="http://sunscript.sun.com/">http://sunscript.sun.com/</a>)</li>
+Tcl/Tk version 8.2 or above (at <a href="http://sunscript.sun.com/">http://sunscript.sun.com/</a>)</li>
 
 <li>
-tkTable version 2.2 or above (at <a href="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</a>)<b>*</b></li>
+tkTable version 2.5 or above (at <a href="http://www.purl.org/net/hobbs/tcl/">http://www.purl.org/net/hobbs/tcl/</a>)<b>*</b></li>
 
 <li>
-the BLT library version 2.4 (at <a href="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</a>)<b>*</b></li>
+the BLT library version 2.4i or above (at <a href="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</a>)<b>*</b></li>
 </ul>
 
 <div align=right><b>*</b><i> many thanks to the authors for these great
@@ -233,16 +235,16 @@ code itself. However, should you want to get more information on those
 extensions, you will find the latest versions:
 <ul>
 <li>
-stooop version 3.7 or above</li>
+stooop version 4.0.1 or above</li>
 
 <li>
-switched version 1.4 or above (included in the stooop distribution)</li>
+switched version 2.2 or above (included in the stooop distribution)</li>
 
 <li>
-scwoop version 2.6 or above</li>
+scwoop version 3.0 or above</li>
 
 <li>
-tkpiechart version 5.3 or above</li>
+tkpiechart version 6.0 or above</li>
 </ul>
 at <a href="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</a>.
 <h3>
@@ -334,7 +336,7 @@ and drop</a> functionality.
 by the module, several instances of the same module, ...) for proper cell
 identification, that string will be placed first in the label. For example,
 data cells originating from the third instance of the random module would
-be labeled: "<i>random&lt;3>: data cell label"</i>.
+be labeled: "<i>random&lt;3>: data cell label</i>".
 <p>Graphical viewers available at this time are BLT graph viewers (see
 images below), side-by-side bars charts, overlapped bars charts, stacked
 bars charts, 2D pie charts and 3D pie charts*. Graph viewers feature an
@@ -501,19 +503,24 @@ Use this menu to gracefully quit the moodss application.
 When selected, this menu launches the following dialog box:
 <center><pre><img SRC="moodss6.gif" height=200 width=446></pre></center>
 The Configuration dialog box allows the user to change global settings
-for the current view (also called a dashbord). This data is stored along when
-saving the configuration to a file (see <a href="#menus.file.save">Save</a> menu).
-<p>Changing configuration choices do not affect the <a href="#menus.edit.preferences">Preferences</a> choices.
+for the current view (also called a dashboard). This data is stored along
+when saving the configuration to a file (see <a href="#menus.file.save">Save</a>
+menu).
+<p>Changing configuration choices do not affect the <a href="#menus.edit.preferences">Preferences</a>
+choices.
 <p>Further and up-to-date help is always provided in the different Configuration
 dialog box screens.
 <h6>
 <a NAME="menus.edit.new"></a>5.1.1.2.2. New</h6>
-Allows the creation of empty viewers of any type (graph chart, overlap bar chart, side bar chart, stacked bar chart, 2D pie chart, 3D pie chart, summary table or free text).
-<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command line</a>).
+Allows the creation of empty viewers of any type (graph chart, overlap
+bar chart, side bar chart, stacked bar chart, 2D pie chart, 3D pie chart,
+summary table or free text).
+<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command
+line</a>).
 <h6>
 <a NAME="menus.edit.preferences"></a>5.1.1.2.3. Preferences</h6>
-The Preferences dialog box is very similar to the <a href="#menus.edit.configuration">configuration</a> dialog
-box.
+The Preferences dialog box is very similar to the <a href="#menus.edit.configuration">configuration</a>
+dialog box.
 <br>It allows the user to change application wide settings, saved in a
 global file (known as an <i>rc</i> file to UNIX people), used for initialization
 when the application is started. Since this file is stored in the user
@@ -543,7 +550,8 @@ all modules poll times.
 <p>The <i>Poll time</i> menu entry is available only when needed, which
 is not the case if all the loaded modules are asynchronous. If this case,
 the <i>Options</i> menu itself is not displayed.
-<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command line</a>).
+<br>This menu is only visible when not running in read-only mode (see <a href="#commandline">Command
+line</a>).
 <h6>
 <a NAME="menus.help"></a>5.1.1.4.&nbsp; Help</h6>
 
@@ -553,16 +561,20 @@ This menu launches an embedded HTML viewer with this very document minus
 the sections related to module development.
 <h6>
 <a NAME="menus.help.modules"></a>5.1.1.4.2. Modules</h6>
-This menu features one sub menu per module,&nbsp; which when selected displays the module's help data.
+This menu features one sub menu per module,&nbsp; which when selected displays
+the module's help data.
 <h6>
 <a NAME="menus.help.copyright"></a>5.1.1.4.3. Copyright</h6>
-Displays the GPL (Gnu General Public License) document, a truly great idea from the Free Software Foundation.
+Displays the GPL (Gnu General Public License) document, a truly great idea
+from the Free Software Foundation.
 <h6>
 <a NAME="menus.help.sourceversions"></a>5.1.1.4.4. Source Versions</h6>
-Displays all the source code file names with their versions, in a table with sort-able columns (as in table viewers).
+Displays all the source code file names with their versions, in a table
+with sort-able columns (as in table viewers).
 <h6>
 <a NAME="menus.help.about"></a>5.1.1.4.5. About</h6>
-Displays version, author, extension authors, license and basic information about moodss.
+Displays version, author, extension authors, license and basic information
+about moodss.
 <h5>
 <a NAME="draganddrop"></a>5.1.1 Drag and drop</h5>
 Drag and drop in moodss tries to behave as the now familiar Windows functionality
