@@ -562,7 +562,7 @@ proc HMset_image {win handle src} {
 
 proc HMgot_image {win image_error} {
 	# if we're in a frame turn on geometry propogation
-	if {[winfo name $win] == "label"} {
+	if {[string equal [winfo name $win] label]} {
 		pack propagate [winfo parent $win] 1
 	}
 	if {[catch {$win configure -image $image_error}]} {
@@ -628,7 +628,7 @@ proc HMlink_callback {win href} {
 
 proc HMextract_param {param key {val ""}} {
 
-	if {$val == ""} {
+	if {[string length $val]==0} {
 		upvar $key result
 	} else {
 		upvar $val result
@@ -666,7 +666,7 @@ proc HMextract_param {param key {val ""}} {
 proc HMstack {win push list} {
 	upvar #0 HM$win var
 	array set tags $list
-	if {$push == ""} {
+	if {[string length $push]==0} {
 		foreach tag [array names tags] {
 			lappend var($tag) $tags($tag)
 		}
@@ -914,7 +914,7 @@ proc HMtag_/form {win param text} {
 	}
 
 	# no submit button - add one
-	if {$form(submit_button) == ""} {
+	if {[string length $form(submit_button)]==0} {
 		HMinput_submit $win {}
 	}
 
@@ -1293,7 +1293,7 @@ proc HMwin_install {win item} {
 	upvar #0 HM$win var
 	$win window create $var(S_insert) -window $item -align bottom
 	$win tag add indent$var(level) $item
-	set focus [expr {[winfo class $item] != "Frame"}]
+	set focus [string compare [winfo class $item] Frame]
 	$item configure -takefocus $focus
 	bind $item <FocusIn> "$win see $item"
 }
@@ -1311,7 +1311,7 @@ proc HMsubmit_button {win form_id param stuff} {
 	set query ""
 	foreach pair $stuff {
 		set value [subst [lindex $pair 1]]
-		if {$value != ""} {
+		if {[string length $value]>0} {
 			set item [lindex $pair 0]
 			lappend query $item $value
 		}
@@ -1329,7 +1329,7 @@ proc HMsubmit_form {win param query} {
 	set sep ""
 	foreach i $query {
 		append result  $sep [HMmap_reply $i]
-		if {$sep != "="} {set sep =} else {set sep &}
+		if {![string equal $sep =]} {set sep =} else {set sep &}
 	}
 	puts $result
 }
@@ -1398,20 +1398,20 @@ proc HMcgiMap {data} {
 auto_load tkFocusOK
 proc tkFocusOK w {
     set code [catch {$w cget -takefocus} value]
-    if {($code == 0) && ($value != "")} {
+    if {($code == 0) && ([string length $value]>0)} {
     if {$value == 0} {
         return 0
     } elseif {$value == 1} {
         return 1
     } else {
         set value [uplevel #0 $value $w]
-        if {$value != ""} {
+        if {[string length $value]>0} {
         return $value
         }
     }
     }
     set code [catch {$w cget -state} value]
-    if {($code == 0) && ($value == "disabled")} {
+    if {($code == 0) && [string equal $value disabled]} {
     return 0
     }
     regexp Key|Focus "[bind $w] [bind [winfo class $w]]"
