@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: lifolbl.tcl,v 1.13 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: lifolbl.tcl,v 2.1 1999/08/28 08:33:26 jfontain Exp $}
 
 # last-in-first-out label generally used at the bottom of an application window for messages display
 
@@ -17,12 +17,12 @@ proc lifoLabel::lifoLabel {this parentPath args} composite {
         [new label $path -font {helvetica -12} -anchor w] body
     pack $composite::($this,header,path) $composite::($this,separator,path) -side left
     pack $composite::($this,body,path) -fill x -expand 1
-    set lifoLabel::($this,lifo) [new lifo]
+    set ($this,lifo) [new lifo]
     composite::complete $this
 }
 
 proc lifoLabel::~lifoLabel {this} {
-    delete $lifoLabel::($this,lifo)
+    delete $($this,lifo)
 }
 
 proc lifoLabel::options {this} {
@@ -58,14 +58,14 @@ proc lifoLabel::set-spacing {this value} {
 
 proc lifoLabel::push {this string} {                                                          ;# user procedure for pushing a string
     if {[string length [set current [$composite::($this,body,path) cget -text]]]>0} {  ;# store current string in stack if non empty
-        xifo::in $lifoLabel::($this,lifo) $current
+        xifo::in $($this,lifo) $current
     }
     $composite::($this,body,path) configure -text $string
 }
 
 proc lifoLabel::pop {this} {                                                                  ;# user procedure for popping a string
     set string {}
-    catch {set string [lifo::out $lifoLabel::($this,lifo)]}
+    catch {set string [lifo::out $($this,lifo)]}
     $composite::($this,body,path) configure -text $string                                           ;# set label text (may be empty)
     return $string
 }
