@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: memstats.tcl,v 1.12 1999/08/01 12:59:55 jfontain Exp $}
+set rcsId {$Id: memstats.tcl,v 1.13 1999/08/27 20:12:32 jfontain Exp $}
 
 
 package provide memstats 1.5
@@ -73,12 +73,12 @@ namespace eval memstats {
         gets $memoryFile; gets $memoryFile; gets $memoryFile                                         ;# skip redundant first 3 lines
         set data(0,1) [lindex [gets $memoryFile] 1]                                                                  ;# total memory
         set data(0,3) [lindex [gets $memoryFile] 1]                                                                   ;# free memory
-        set data(0,2) [expr {$data(0,1)-$data(0,3)}]                                                                  ;# used memory
         set data(0,4) [lindex [gets $memoryFile] 1]                                                                 ;# shared memory
         set data(0,5) [lindex [gets $memoryFile] 1]                                                                       ;# buffers
         set data(1,6) [lindex [gets $memoryFile] 1]                                                                 ;# cached memory
         set data(1,1) [lindex [gets $memoryFile] 1]                                                                    ;# total swap
         set data(1,3) [lindex [gets $memoryFile] 1]                                                                     ;# free swap
+        set data(0,2) [expr {$data(0,1)-$data(0,3)-$data(0,5)-$data(1,6)}]          ;# used memory = total - free - buffers - cached
         set data(1,2) [expr {$data(1,1)-$data(1,3)}]                                                                    ;# used swap
         if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
             close $memoryFile
