@@ -1,6 +1,6 @@
 #!/bin/sh
 # the next line restarts using the interpreter \
-exec wish "$0" "$@"
+exec wish8.2 "$0" "$@"
 
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
@@ -12,7 +12,7 @@ proc recordRCSId {variableName empty operation} {
 }
 trace variable ::rcsId w recordRCSId                                                                ;# keep track of RCS identifiers
 
-set rcsId {$Id: moodss.tcl,v 1.176 1999/08/08 19:33:47 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 2.3 1999/09/22 12:47:11 jfontain Exp $}
 
 
 proc printUsage {exitCode} {
@@ -51,8 +51,10 @@ foreach {short long} {-f --file -h --help -p --poll-time -r --read-only -S --sta
 }
 
 if {
-    [info exists arguments(-h)]||[info exists arguments(-he)]||[info exists arguments(-hel)]||[info exists arguments(-help)]||
-    (([llength $argv]==0)&&![info exists arguments(-f)]&&![info exists arguments(--show-modules)])
+    [info exists arguments(-h)]||[info exists arguments(-he)]||[info exists arguments(-hel)]||[info exists arguments(-help)]||(
+        ([llength $argv]==0)&&
+        ![info exists arguments(-f)]&&![info exists arguments(--show-modules)]&&![info exists arguments(--version)]
+    )
 } {
     printUsage 1
 }
@@ -70,13 +72,14 @@ source preferen.tcl
 source config.tcl
 configuration::load [preferences::read]                                               ;# initialize from rc file as soon as possible
 
-lappend auto_path /usr/lib/moodss .    ;# search in current directory sub-directories for development and rpm installation directory
+# search in current directory sub-directories for development and Tcl package moodss sub-directory
+lappend auto_path $::tcl_pkgPath/moodss .
 
-if {[catch {package require stooop 3.7}]} {
+if {[catch {package require stooop 4.0.1}]} {
     source stooop.tcl                                                                     ;# in case stooop package is not installed
 }
 namespace import stooop::*
-if {[catch {package require switched 1.4}]} {                                           ;# in case switched package is not installed
+if {[catch {package require switched 2.2}]} {                                           ;# in case switched package is not installed
     source switched.tcl
 }
 
@@ -87,7 +90,7 @@ if {[info exists arguments(--show-modules)]} {
     exit                                                                                                                     ;# done
 }
 
-if {[catch {package require scwoop 2.6}]} {
+if {[catch {package require scwoop 3.0}]} {
     source scwoutil.tcl
     source scwoop.tcl                                                                     ;# in case scwoop package is not installed
     source bindings.tcl
@@ -97,7 +100,7 @@ if {[catch {package require scwoop 2.6}]} {
     source panner.tcl
     source scroll.tcl
 }
-if {[catch {package require tkpiechart 5.3}]} {                                       ;# in case tkpiechart package is not installed
+if {[catch {package require tkpiechart 6.0}]} {                                       ;# in case tkpiechart package is not installed
     source pielabel.tcl
     source boxlabel.tcl
     source canlabel.tcl
@@ -108,7 +111,7 @@ if {[catch {package require tkpiechart 5.3}]} {
     source objselec.tcl
     source pie.tcl
 }
-if {[catch {package require Tktable 2}]} {                                               ;# in case tkTable package is not installed
+if {[catch {package require Tktable 2.5}]} {                                             ;# in case tkTable package is not installed
     switch $tcl_platform(platform) {
         unix {
             load ./Tktable.so.2.5
@@ -178,8 +181,8 @@ source wcbEntry.tcl
 set readOnly [info exists arguments(-r)]
 set global::static [info exists arguments(-S)]
 
-set scroll [new scroll canvas .]
-set global::canvas $composite::($scroll,scrolled,path)
+set global::scroll [new scroll canvas .]
+set global::canvas $composite::($global::scroll,scrolled,path)
 $global::canvas configure -highlightthickness 0 -takefocus 0
 trace variable global::canvasHeight w updateCanvasSize                                       ;# track changes for good user feedback
 trace variable global::canvasWidth w updateCanvasSize
@@ -192,8 +195,8 @@ set global::windowManager [new canvasWindowManager $global::canvas]
 if {[info exists ::geometry]} {                                                               ;# command line geometry was specified
     wm geometry . $::geometry
 } elseif {[info exists initializer]} {
-    foreach {width height} [record::sizes $initializer] {}                                   ;# used stored geometry for main window
-    wm geometry . ${width}x$height
+    foreach {width height} [record::sizes $initializer] {}                                   ;# used stored geometry for scroll area
+    composite::configure $global::scroll -width $width -height $height
 } else {
     wm geometry . 400x300
 }
@@ -208,7 +211,7 @@ if {[string compare $tcl_platform(platform) unix]==0} {
 if {!$readOnly} {
     pack [createDragAndDropZone .] -fill x
 }
-pack $widget::($scroll,path) -fill both -expand 1
+pack $widget::($global::scroll,path) -fill both -expand 1
 
 set modules::(synchronous) {}                                                                    ;# save list of synchronous modules
 set names {}
