@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: mounts.tcl,v 1.9 1999/08/01 12:59:55 jfontain Exp $}
+set rcsId {$Id: mounts.tcl,v 1.10 1999/08/27 20:03:13 jfontain Exp $}
 
 
 package provide mounts 1.5
@@ -127,9 +127,8 @@ namespace eval mounts {
         variable index
         variable data
 
-        foreach directory [array names index] {                                                       ;# cleanup disappeared entries
+        foreach {directory row} [array get index] {                                                   ;# cleanup disappeared entries
             if {[info exists current($directory)]} continue
-            set row $index($directory)
             unset index($directory) data($row,0) data($row,1) data($row,2) data($row,3) data($row,4) data($row,5) data($row,6)
         }
     }
