@@ -1,13 +1,13 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: ps.tcl,v 1.39 1999/08/01 12:59:55 jfontain Exp $}
+set rcsId {$Id: ps.tcl,v 2.1 1999/09/22 11:18:16 jfontain Exp $}
 
 
 # System dependent process data access procedures. Only Linux is supported at this time (who needs another OS?).
 # Corresponding pkgIndex.tcl file content: package ifneeded ps 1.4 "source [file join $dir ps.tcl]"
 
-package provide ps 1.8
+package provide ps 2.0
 package require network 1.3
 
 namespace eval ps {
@@ -117,20 +117,6 @@ namespace eval ps {
         return {}                                                                                                  ;# not a terminal
     }
 
-    proc nullToSpace {data} {                       ;# replace null characters with space characters ### use regsub with Tcl 8.1 ###
-        set length [string length $data]
-        set string {}
-        for {set index 0} {$index<$length} {incr index} {                   ;# replace null characters by spaces (regsub fails here)
-            set character [string index $data $index]
-            if {[string compare $character \000]==0} {
-                append string { }
-            } else {
-                append string $character
-            }
-        }
-        return $string
-    }
-
     proc update {} {
         variable remote
 
@@ -182,7 +168,7 @@ namespace eval ps {
                     unset uid($pid)
                     continue
                 }
-                set cmdline($pid) [nullToSpace $line]                                   ;# command line arguments are null separated
+                regsub -all {\0} $line { } cmdline($pid) ;# command line arguments are null separated: replace with space characters
             }
 
             if {[catch {open $pid/stat} file]} {                                                     ;# process may have disappeared
