@@ -1,14 +1,14 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: random.tcl,v 1.24 1999/01/17 20:14:53 jfontain Exp $}
+set rcsId {$Id: random.tcl,v 1.26 1999/07/20 20:25:29 jfontain Exp $}
 
 # module sample file with random data
 
 # corresponding pkgIndex.tcl file content:
 # package ifneeded random 4.0 "source [file join $dir random.tcl]"
 
-package provide random 4.2
+package provide random 4.3
 
 namespace eval random {                                                                    ;# namespace name must match package name
     # Module data is arranged in a single array that can be used by many views, such as tables, graphs, pies,...
@@ -47,6 +47,9 @@ namespace eval random {
     #   appropriate initialize procedure must be provided by the module (see initialize procedure example in this module).
     #   The core will take care of parsing the command line and reject any invalid switch / value combination for the module.
     #   The switches value may not be changed in the initialize procedure.
+    # - identifier: optional, ignore for moodss versions before 8.0. A string that uniquely identifies this module. It will be
+    #   displayed by the core in the initial data tables title area and data cell labels in viewers. This feature can be used for
+    #   example in modules that gather data from a remote host: in such a case, the identifier could be set to dataType(hostName).
     array set data {
         updates 0
         0,label name 0,type ascii 0,message {user name}
@@ -61,7 +64,7 @@ namespace eval random {
             {visibleColumns {0 1 3 4} sort {1 decreasing}}
             {visibleColumns {0 2 4} sort {2 decreasing}}
         }
-        switches {-a 0 --asynchronous 0}
+        switches {-a 0 --asynchronous 0 -i 0 --identify 0}
     }
     set file [open [file join $::packageDirectory(random) random.htm]]                      ;# directory is set in pkgIndex.tcl file
     set data(helpText) [read $file]                                   ;# initialize HTML help data from file in module sub-directory
@@ -96,6 +99,9 @@ namespace eval random {
             array set data {pollTimes -10}
             after 3000 random::update                                                                             ;# boot simulation
         }
+        if {[info exists options(-i)]||[info exists options(--identify)]} {                   ;# generate a unique module identifier
+            set data(identifier) "random [expr {int(rand()*100)}]"
+        }
     }
 
     # The dynamic data array index is the row number followed by the column number separated by a comma.
