@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.27 1999/08/08 20:37:42 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.29 1999/09/18 09:38:54 jfontain Exp $}
 
 
 class record {
@@ -40,7 +40,8 @@ class record {
         puts $file "configuration {$list}"
 
         # main window coordinates are not saved as it would be bad manners to force initial window placement
-        puts $file "width [winfo width .] height [winfo height .]"
+        set path $::widget::($global::scroll,path)                   ;# use scroll area size as icons area may or may not be present
+        puts $file "width [winfo width $path] height [winfo height $path]"
         puts $file "pollTime $global::pollTime"
         puts $file "modules \{"
         foreach module $modules::(namespaces) {
@@ -130,8 +131,8 @@ class record {
             set viewer(level) {}        ;# for backward compatibility when level was not stored in save file (versions 5.1 and down)
             array set viewer $data($id)
             set options {}                                  ;# gather viewer specific switched options in a switch / value pair list
-            foreach name [array names viewer -*] {
-                lappend options $name $viewer($name)
+            foreach {name value} [array get viewer -*] {
+                lappend options $name $value
             }
             lappend list $viewer(class) $viewer(cells) $viewer(x) $viewer(y) $viewer(width) $viewer(height) $viewer(level) $options
         }
@@ -166,8 +167,8 @@ class record {
     proc tableOptions {this module creationIndex} {
         tableData $this $module $creationIndex data
         set options {}                                       ;# gather table specific switched options in a switch / value pair list
-        foreach name [array names data -*] {
-            lappend options $name $data($name)
+        foreach {name value} [array get data -*] {
+            lappend options $name $value
         }
         return $options
     }
