@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: route.tcl,v 1.15 1999/08/01 12:59:55 jfontain Exp $}
+set rcsId {$Id: route.tcl,v 1.16 1999/08/27 20:02:23 jfontain Exp $}
 
 
 package provide route 1.4
@@ -111,9 +111,8 @@ namespace eval route {
             set data($row,7) $metric
             set current($address) {}
         }
-        foreach address [array names index] {                                                         ;# cleanup disappeared entries
+        foreach {address row} [array get index] {                                                     ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
-            set row $index($address)
             unset index($address) data($row,0) data($row,1) data($row,2) data($row,3)
         }
         if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
