@@ -1,4 +1,4 @@
-set rcsId {$Id: scroll.tcl,v 1.9 1998/10/04 14:57:52 jfontain Exp $}
+set rcsId {$Id: scroll.tcl,v 2.1 1999/08/16 20:30:54 jfontain Exp $}
 
 # generic scroll widget with automatic scrollbars for scrolling widgets with the common tk scroll interface
 
@@ -21,8 +21,8 @@ class scroll {
         grid rowconfigure $path 0 -weight 1
         grid columnconfigure $path 0 -weight 1
 
-        set scroll::($this,0,1,path) $composite::($this,vertical,path)
-        set scroll::($this,1,0,path) $composite::($this,horizontal,path)
+        set ($this,0,1,path) $composite::($this,vertical,path)
+        set ($this,1,0,path) $composite::($this,horizontal,path)
 
         composite::complete $this
     }
@@ -74,7 +74,7 @@ class scroll {
     }
 
     proc update {this row column first last} {
-        set path $scroll::($this,$row,$column,path)
+        set path $($this,$row,$column,path)
         foreach {previousFirst previousLast} [$path get] {}
         if {($first!=$previousFirst)||($last!=$previousLast)} {                                        ;# update only when necessary
             $path set $first $last
@@ -91,10 +91,10 @@ class scroll {
                 grid $composite::($this,filler,path) -sticky nsew -column 1 -row 1
             }
         } else {
-            foreach {first last} [$scroll::($this,$column,$row,path) get] {}                        ;# look at other scrollbar range
+            foreach {first last} [$($this,$column,$row,path) get] {}                                ;# look at other scrollbar range
             if {$visible&&(($last-$first)>=1)} {                       ;# unmap both scrollbars at the same time to avoid vibrations
-                grid remove $scroll::($this,0,1,path)
-                grid remove $scroll::($this,1,0,path)
+                grid remove $($this,0,1,path)
+                grid remove $($this,1,0,path)
                 grid remove $composite::($this,filler,path)
             }
         }
