@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: tablesel.tcl,v 1.4 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: tablesel.tcl,v 1.5 1999/01/31 17:22:58 jfontain Exp $}
 
 # implements selection on table cells, identified by row and column indices
 
@@ -40,7 +40,4 @@ class tableSelector {
         }
     }
 
-    proc list {this} {
-        return [lsort -integer [selector::_list $this]]
-    }
 }
