@@ -1,15 +1,15 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: viewer.tcl,v 1.31 1999/07/18 14:01:56 jfontain Exp $}
+set rcsId {$Id: viewer.tcl,v 2.1 1999/08/28 09:32:13 jfontain Exp $}
 
 class viewer {                                                                             ;# handle viewers related functionalities
     # viewers do not derive from a common interface class but rather support a common set a options through the composite class
 
-    set viewer::(list) {}
+    set ::viewer::(list) {}
 
     proc viewer {this} {
-        lappend viewer::(list) $this
+        lappend ::viewer::(list) $this
     }
 
     proc ~viewer {this} {
@@ -19,10 +19,10 @@ class viewer {
             trace vdelete ${array}(updates) w "viewer::update $this $array"
         }
         catch {unset ${this}traces}
-        if {[info exists viewer::($this,drop)]} {
-            delete $viewer::($this,drop)
+        if {[info exists ($this,drop)]} {
+            delete $($this,drop)
         }
-        ldelete viewer::(list) $this
+        ldelete ::viewer::(list) $this
     }
 
     virtual proc supportedTypes {this}
@@ -57,14 +57,14 @@ class viewer {
     proc parse {dataCell arrayName rowName columnName typeName} {
         upvar $arrayName array $rowName row $columnName column $typeName type
 
-        if {![regexp {^(.*)\(([0-9]+),([0-9]+)\)$} $dataCell dummy array row column]||($row<0)||($column<0)} {
+        if {([scan $dataCell {%[^(](%u,%u)} array row column]!=3)||($row<0)||($column<0)} {
             error "\"$dataCell\" is not a valid array cell"
         }
         set type [set ${array}($column,type)]
     }
 
     proc updateInterval {value} {                                             ;# static procedure for updating all viewers intervals
-        foreach viewer $viewer::(list) {
+        foreach viewer $(list) {
             catch {composite::configure $viewer -interval $value}                 ;# some viewers do not support the interval option
         }
     }
@@ -117,7 +117,7 @@ class viewer {
     }
 
     proc setupDropSite {this path} {                                 ;# allow dropping of data cells, viewer mutation or kill action
-        set viewer::($this,drop) [new dropSite -path $path -formats {DATACELLS VIEWER KILL} -command "viewer::handleDrop $this"]
+        set ($this,drop) [new dropSite -path $path -formats {DATACELLS VIEWER KILL} -command "viewer::handleDrop $this"]
     }
 
     proc handleDrop {this} {
@@ -131,10 +131,10 @@ class viewer {
     }
 
     proc mutate {this class} {
-        if {[string compare $class [classof $this]]==0} return                       ;# no need to create a viewer of the same class
+        if {[string equal $class [classof $this]]} return                            ;# no need to create a viewer of the same class
         set viewer [eval new $class $global::canvas -draggable [composite::cget $this -draggable]]
         foreach list [composite::configure $viewer] {
-            if {[string compare [lindex $list 0] -interval]==0} {                                 ;# viewer supports interval option
+            if {[string equal [lindex $list 0] -interval]} {                                      ;# viewer supports interval option
                 composite::configure $viewer -interval $global::pollTime                                  ;# so use current interval
                 break                                                                                                        ;# done
             }
